@@ -1,5 +1,5 @@
 # conver string to byte array
-def string_to_bytearray(self, string):
+def string_to_bytearray(string):
     if string is None:
         return None                    
     b = bytearray()
